.. HCIPy documentation master file, created by
   sphinx-quickstart on Thu Apr 13 16:08:06 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to HCIPy's documentation!
=================================

HCIPy is a framework written in Python for high contrast imaging simulation work. It implements adaptive optics simulation, coronagraphy and optical diffraction calculations.

.. caution::
    HCIPy is still in active development. Some functions may not work as expected.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   getting_started/index
   tutorials/index
   api